@@ -1,5 +1,5 @@
 import numpy as np
-import ccalafiore.strings as cc_str
+# import ccalafiore.strings as cc_str
 
 
 def numeric_indexes_to_slice(indexes):
@@ -42,6 +42,11 @@ def format_shape_arguments(dict_arguments, target_shape):
 
     if isinstance(target_shape, list) or isinstance(target_shape, tuple):
         target_shape = np.asarray(target_shape, dtype=int)
+    if isinstance(target_shape, np.ndarray):
+        pass
+    else:
+        target_shape = np.asarray([target_shape], dtype=int)
+
     n_axes = target_shape.size
 
     # n_arguments = len(arguments)
