@@ -1,14 +1,13 @@
-# import os
 
 __name__ = 'ccalafiore'
-__version__ = '000.000.039'
+__version__ = '000.000.041'
 __author__ = 'Calafiore Carmelo'
 __author_email__ = 'c.calafiore@essex.ac.uk'
 __maintainer_email__ = 'c.calafiore@essex.ac.uk'
 __all__ = [
-    'array', 'Checker', 'clock', 'combinations', 'directory', 'display', 'download',
-    'Formatter', 'maths', 'mixamo', 'plot', 'preprocessing', 'shut_down', 'stats',
-    'strings']
+    'array', 'Checker', 'clock', 'combinations', 'directory', 'download',
+    'Formatter', 'maths', 'mixamo', 'nn', 'plot', 'preprocessing', 'shut_down', 'stats',
+    'strings', 'txt']
 # __all__ = []
 # cwd = os.path.dirname(__file__)
 # format_modules = '.py'
