@@ -1,6 +1,6 @@
 from .combinations import n_conditions_to_combinations
 from . import Formatter as cc_Formatter
-from .maths import convert_to_int_or_float
+from .maths import convert_to_int_or_float, rint
 import numpy as np
 import glob
 import math
@@ -385,235 +385,7 @@ def shuffle_in_any_dimension(data, axis=0):
     return data_shuffle
 
 
-def csv_file_to_array(filename, rows, columns, dtype=None):
-
-    with open(filename, newline='') as csvfile:
-        reader = csv.reader(csvfile, delimiter=',')
-        table = np.asarray(list(reader), dtype=dtype)
-
-    indexes = tuple(cc_Formatter.numeric_indexes_to_slice([rows, columns]))
-    array = table[indexes]
-
-    return array
-
-
-def csv_file_to_arrays(filename, rows, columns, dtype=None):
-    try:
-        n_arrays_from_rows = len(rows)
-    except TypeError:
-        rows = [rows]
-        n_arrays_from_rows = 1
-    try:
-        n_arrays_from_columns = len(columns)
-    except TypeError:
-        columns = [columns]
-        n_arrays_from_columns = 1
-
-    if n_arrays_from_rows != n_arrays_from_columns:
-        if n_arrays_from_rows == 1:
-            rows = list(rows) * n_arrays_from_columns
-            n_arrays_from_rows = n_arrays_from_columns
-        elif n_arrays_from_columns == 1:
-            columns = list(columns) * n_arrays_from_rows
-            n_arrays_from_columns = n_arrays_from_rows
-        else:
-            raise ValueError(
-                'The following assumption is not met:\n'
-                '\t n_arrays_from_rows' + ' \u003D ' + 'n_arrays_from_columns')
-
-    n_arrays = n_arrays_from_rows
-    try:
-        n_dtypes = len(dtype)
-    except TypeError:
-        dtype = [dtype]
-        n_dtypes = 1
-    if n_arrays != n_dtypes:
-        if n_dtypes == 1:
-            dtype = list(dtype) * n_arrays
-        else:
-            raise ValueError(
-                'The following assumption is not met:\n'
-                '\t(n_dtypes \u003D n_arrays_from_rows) OR (n_dtypes \u003D n_arrays_from_columns)')
-
-    with open(filename, newline='') as csvfile:
-        reader = csv.reader(csvfile, delimiter=',')
-        table = np.asarray(list(reader), dtype='U')
-
-    n_axes_per_text = 2
-    arrays = [None] * n_arrays
-    for a in range(n_arrays):
-        indexes = tuple(cc_Formatter.numeric_indexes_to_slice([rows[a], columns[a]]))
-        if (dtype[a] is None) or (dtype[a] == str) or ('U' in dtype[a][:3]):
-            arrays[a] = table[indexes]
-        else:
-            arrays[a] = table[indexes].astype(dtype[a])
-    return arrays
-
-
-def conditions_of_csv_files_to_arrays(conditions_of_directories, rows, columns, dtype=None):
-
-    n_axes_directories = len(conditions_of_directories)
-    n_conditions_directories = np.empty(n_axes_directories, dtype=int)
-    for i in range(n_axes_directories):
-        n_conditions_directories[i] = len(conditions_of_directories[i])
-    # logical_indexes_conditions = n_conditions_directories > 1
-    combinations_directories = n_conditions_to_combinations(n_conditions_directories)
-    n_combinations_directories = combinations_directories.shape[0]
-    axes_directories_squeezed = n_conditions_directories > 1
-    n_axes_directories_squeezed = np.sum(axes_directories_squeezed)
-
-    try:
-        n_arrays_from_rows = len(rows)
-    except TypeError:
-        rows = [rows]
-        n_arrays_from_rows = 1
-    try:
-        n_arrays_from_columns = len(columns)
-    except TypeError:
-        columns = [columns]
-        n_arrays_from_columns = 1
-
-    if n_arrays_from_rows != n_arrays_from_columns:
-        if n_arrays_from_rows == 1:
-            rows = list(rows) * n_arrays_from_columns
-            n_arrays_from_rows = n_arrays_from_columns
-        elif n_arrays_from_columns == 1:
-            columns = list(columns) * n_arrays_from_rows
-            n_arrays_from_columns = n_arrays_from_rows
-        else:
-            raise ValueError(
-                'The following assumption is not met:\n'
-                '\t n_arrays_from_rows' + ' \u003D ' + 'n_arrays_from_columns')
-
-    n_arrays = n_arrays_from_rows
-    try:
-        n_dtypes = len(dtype)
-    except TypeError:
-        dtype = [dtype]
-        n_dtypes = 1
-    if n_arrays != n_dtypes:
-        if n_dtypes == 1:
-            dtype = list(dtype) * n_arrays
-        else:
-            raise ValueError(
-                'The following assumption is not met:\n'
-                '\t(n_dtypes \u003D n_arrays_from_rows) OR (n_dtypes \u003D n_arrays_from_columns)')
-
-    n_axes_per_csv = 2
-    indexes = [None] * n_arrays
-    arrays = [None] * n_arrays
-    for a in range(n_arrays):
-        indexes[a] = tuple(cc_Formatter.numeric_indexes_to_slice([rows[a], columns[a]]))
-
-    directory_csv_d = os.path.join(*[
-        conditions_of_directories[i][0] for i in range(n_axes_directories)])
-
-    with open(directory_csv_d, newline='') as csvfile:
-        reader = csv.reader(csvfile, delimiter=',')
-        array_csv_d = np.asarray(list(reader), dtype='U')
-
-    indexes_out = [None] * n_arrays
-    for a in range(n_arrays):
-        if dtype[a] is None:
-            dtype[a] = 'U'
-
-        array_a_d = array_csv_d[indexes[a]]
-        shape_array_a_d = np.asarray(array_a_d.shape, dtype=int)
-        shape_array_a = np.append(
-            n_conditions_directories[axes_directories_squeezed], shape_array_a_d)
-
-        arrays[a] = np.empty(shape_array_a, dtype=dtype[a])
-        n_axes_a = shape_array_a.size
-        indexes_out = np.empty(n_axes_a, dtype=object)
-        indexes_out[:] = slice(None)
-
-    for d in range(n_combinations_directories):
-
-        directory_csv_d = os.path.join(*[
-            conditions_of_directories[i][combinations_directories[d, i]] for i in range(n_axes_directories)])
-
-        with open(directory_csv_d, newline='') as csvfile:
-            reader = csv.reader(csvfile, delimiter=',')
-            array_csv_d = np.asarray(list(reader), dtype='U')
-
-        indexes_out[slice(0, n_axes_directories_squeezed, 1)] = (
-            combinations_directories[d, axes_directories_squeezed])
-
-        for a in range(n_arrays):
-            arrays[a][tuple(indexes_out)] = array_csv_d[indexes[a]]  # .astype(dtype[a])
-
-    return arrays
-
-
-def lines_to_csv_file(directory, lines, headers=None):
-    with open(directory, 'w', newline='') as csv_file:
-        writer = csv.writer(csv_file, delimiter=',')
-        if headers is not None:
-            writer.writerow(headers)
-        writer.writerows(lines)
-
-
-def n_csv_files_to_array_old(directories_csv_files, names_csv_files_in_directories=False, rows=slice(None), columns=slice(None), data_type=None):
-
-    print('using the funtion n_csv_files_to_array().\n'
-          'In the future versions of ccalafiore, it will be removed.\n'
-          'Consider using conditions_of_csv_files_to_arrays()')
-    array = None
-
-    n_axes_directories = len(directories_csv_files)
-    n_conditions_directories = np.empty(n_axes_directories, dtype=int)
-    for a in range(n_axes_directories):
-        n_conditions_directories[a] = len(directories_csv_files[a])
-
-    logical_indexes_conditions = n_conditions_directories > 1
-
-    combinations_directories = n_conditions_to_combinations(n_conditions_directories)
-    n_combinations_directories = combinations_directories.shape[0]
-
-    for d in range(n_combinations_directories):
-
-        directory = directories_csv_files[0][combinations_directories[d, 0]]
-        for a in range(1, n_axes_directories):
-            directory = os.path.join(
-                directory, directories_csv_files[a][combinations_directories[d, a]])
-
-        if names_csv_files_in_directories:
-            files_per_directory = [directory]
-        else:
-            files_per_directory = glob(os.path.join(directory, '*.csv'))
-
-        n_files_per_directory = len(files_per_directory)
-
-        start_row_f_file = 0
-        for f in range(n_files_per_directory):
-
-            array_per_file = np.genfromtxt(files_per_directory[f], delimiter=',', dtype=data_type)[rows, columns]
-
-            if array is None:
-
-                shape_array_per_file = np.asarray(array_per_file.shape, dtype=int)
-
-                shape_array = np.asarray([
-                    *n_conditions_directories[logical_indexes_conditions],
-                    n_files_per_directory * shape_array_per_file[0],
-                    *shape_array_per_file[1:]
-                ], dtype=int)
-
-                array = np.empty(shape_array, dtype=data_type)
-
-            end_row_f_file = (f + 1) * shape_array_per_file[0]
-
-            indexes_array = tuple(
-                [*combinations_directories[d][logical_indexes_conditions],
-                 slice(start_row_f_file, end_row_f_file)])
-
-            array[indexes_array] = array_per_file
-            start_row_f_file = end_row_f_file
-
-    return array
-
-
-def split(array, n_slices, axis=0):
+def split_by_n(array, n_slices, axis=0):
 
     shape_array = np.array(array.shape)
 
@@ -649,6 +421,72 @@ def split(array, n_slices, axis=0):
     return sliced_array
 
 
+def split_by_percentages(array, p_samples, axis=0, shuffle=False, sort=False):
+
+    N = array.shape[axis]
+    S = len(p_samples)
+    M = np.empty(S, dtype='i')
+
+    for s in range(S):
+        M[s] = rint(N / 100 * p_samples[s])
+
+    sum_M = M.sum()
+    if sum_M != N:
+        if sum_M < N:
+            s = 0
+            M[s] += 1
+            while sum_M < N:
+                s += 1
+                M[s] += 1
+        else:
+            s = 0
+            M[s] -= 1
+            while sum_M < N:
+                s += 1
+                M[s] -= 1
+
+
+    indexes_splitting = np.empty(S - 1, dtype='i')
+    for s in range(S - 1):
+        indexes_splitting[s] = M[slice(0, s + 1, 1)].sum()
+
+    if shuffle:
+        n_axes = len(array.shape)
+        indexes_array = np.empty(n_axes, dtype=object)
+        indexes_array[:] = slice(0, None, 1)
+        indexes_array[axis] = np.random.permutation(N)
+        arrays = np.split(array[tuple(indexes_array)], indexes_splitting, axis=axis)
+
+        # arrays = np.split(shuffle_in_any_dimension(array, axis=axis), indexes_splitting, axis=axis)
+        if sort:
+            indexes_perm = np.split(indexes_array[axis], indexes_splitting, axis=axis)
+            indexes_recover = [None] * S  # type: list
+            # arrays_new = [None] * S  # type: list
+            for s in range(S):
+                indexes_recover[s] = np.empty(M[s], dtype='i')
+                start_s = 0
+                for m in range(M[s]):
+                    for i in range(start_s, N):
+                        indexes_found = np.where(i == indexes_perm[s])[0]
+                        n_indexes_found = len(indexes_found)
+                        if n_indexes_found == 1:
+                            indexes_recover[s][m] = indexes_found[0]
+                            # np.delete(indexes_perm[s], indexes_found)
+                            start_s = i + 1
+                            break
+
+                indexes_array[axis] = indexes_recover[s]
+                arrays[s] = arrays[s][tuple(indexes_array)]
+                # arrays_new[s] = arrays[s][tuple(indexes_array)]
+                # indexes_recover[s] = [np.where(i == indexes_perm[s])[0][0] for i in range(N)]
+                # c = b[indexes_recover]
+                # arrays[s].sort()
+    else:
+        arrays = np.split(array, indexes_splitting, axis=axis)
+
+    return arrays
+
+
 def pad_array_from_n_samples_target(array, n_samples_target=1, axis=0):
 
     try:
@@ -757,7 +595,7 @@ def centered_indexes_to_normal_indexes(
     return normal_indexes
 
 
-class MyRange:
+class Range:
     def __init__(self, raw_range):
         if isinstance(raw_range, dict):
             keys = ['start', 'stop', 'step']
@@ -798,7 +636,7 @@ class MyRange:
                 start, stop, step = raw_range
             else:
                 raise ValueError('raw_range has to have at least 1 element. {} are given'.format(n_elements))
-        elif isinstance(raw_range, numbers.Number):
+        elif isinstance(raw_range, (numbers.Number, None)):
             start = 0
             stop = raw_range
             step = 1
@@ -860,6 +698,9 @@ class MyRange:
             step=len_each_equal_ranges)
         return centers
 
+    def to_slice(self):
+        return slice(self.start, self.stop, self.step)
+
 
 def read_image(directory, order='RGB'):
     array_bgr = cv2.imread(directory, cv2.IMREAD_COLOR)
