@@ -1,19 +1,19 @@
 from os.path import isfile as os_path_isfile
 from time import sleep
+from . import clock as cc_clock
 
 
 def wait_downloading(directory_saved_as, max_seconds_wait=60):
 
+    timer = cc_clock.Timer()
     wait = True
-    downloaded = False
-    seconds_wait = 0
     while wait:
+
         if os_path_isfile(directory_saved_as):
             wait = False
-            downloaded = True
-
-        wait = wait and (seconds_wait < max_seconds_wait)
+        elif timer.get_time() > max_seconds_wait:
+            raise TimeoutError
         sleep(1)
-        seconds_wait += 1
-            
-    return downloaded
+
+
+
