@@ -1,5 +1,5 @@
 import numpy as np
-from ccalafiore.combinations import make_combinations_of_conditions_as_unique_values
+# from ccalafiore.combinations import make_combinations_of_conditions_as_unique_values
 
 
 def passwords_in_txt_files(directory_txt_file, n_digits=3):
