@@ -105,21 +105,21 @@ def from_2_arrays(
     axis_variables_table_output = axis_variables_table_input + np.sum(
         axes_inserting <= axis_variables_table_input)
     axis_samples_output = axis_samples_input + np.sum(axes_inserting <= axis_samples_input)
-    changed = True
-    while changed:
-        changed = False
+    need_to_check = True
+    while need_to_check:
+        need_to_check = False
         while axis_variables_table_output in axes_inserting:
             axis_variables_table_output += 1
-            changed = True
+            need_to_check = True
         while axis_samples_output in axes_inserting:
             axis_samples_output += 1
-            changed = True
+            need_to_check = True
         if axis_variables_table_output == axis_samples_output:
-            changed = True
             if axis_variables_table_input > axis_samples_input:
                 axis_variables_table_output += 1
             elif axis_variables_table_input < axis_samples_input:
                 axis_samples_output += 1
+            need_to_check = True
 
     axes_array_output = np.arange(n_axes_array_output)
     axes_non_axis_variables_table_output = axes_array_output[axes_array_output != axis_variables_table_output]
