@@ -182,3 +182,13 @@ def get_list_of_n_variable_names(variables, n_outer_frames=1):
             max_string_length = string_length_i
     return np.asarray(list_of_names, dtype=('<U' + str(max_string_length)))
 
+
+def format_float_to_str(value_float, n_decimals=None):
+    if n_decimals is None:
+        template = '{:f}'
+    else:
+        template = '{:.' + str(n_decimals) + 'f}'
+
+    value_str = template.format(value_float)
+    return value_str
+
